multidim.covertree.CoverLevel.plot — GDA Toolbox v1.0 Manual

# multidim.covertree.CoverLevel.plot

`CoverLevel.` `plot`(canvas, show_balls=True, show_adults=True, show_hulls=False, color='purple')

  Plot a single level of a `CoverTree`

  See the example at example-covertree

  Parameters: | canvas : `bokeh.plotting.figure.Figure` as obtained from `canvas = bokeh.plotting.figure()` show_balls : bool Draw the covering balls at this level. Default: True show_adults : bool Draw the adults at this level. Default: True show_hulls : bool Draw the convex hulls of the childeren of each adult. Note – this works only with matplotlib for now, not bokeh. Default: False color : str Name of color to use for cover-tree balls and hulls. Default: ‘purple’

  References

#### Previous topic

multidim.covertree.CoverLevel.find_label_weights

#### Next topic

multidim.covertree.CoverLevel.plot_data_title